#!/bin/sh

if [ -z "$1" ]; then
  echo "Usage: update.sh /path/to/mozilla/js/src"
  echo "Example: update.sh ~/mozilla/js/src"
  exit
fi

find . -maxdepth 1 -type f \
! -regex '.*/\(\.\|Makefile\|SConscript\|CMake\|update.sh\).*' -a \
! -name "*.patch" -exec \
sh -c "if [ -e '$1/{}' ]; then cp -fp '$1/{}' '{}'; else rm -f '{}'; fi" \;

patch jsemit.c jsemit.patch
patch jsscan.c jsscan.patch
